<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.pedigreeonline.com
 * @since             1.1.0
 * @package           Pedigree_Online
 *
 * @wordpress-plugin
 * Plugin Name:       Pedigree Online
 * Plugin URI:        https://www.pedigreeonline.com/wordpress
 * Description:       Allows you to embed pedigrees of animals that are listed on PedigreeOnline.com into your Wordpress Site using shortcodes and customized colors.
 * Version:           1.1.2
 * Author:            PedigreeOnline.com, Inc
 * Author URI:        https://www.pedigreeonline.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       pedigree-online
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'PEDIGREE_ONLINE_VERSION', '1.1.2' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-pedigree-online-activator.php
 */
function activate_pedigree_online() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-pedigree-online-activator.php';
	Pedigree_Online_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-pedigree-online-deactivator.php
 */
function deactivate_pedigree_online() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-pedigree-online-deactivator.php';
	Pedigree_Online_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_pedigree_online' );
register_deactivation_hook( __FILE__, 'deactivate_pedigree_online' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-pedigree-online.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_pedigree_online() {

	$plugin = new Pedigree_Online();
	$plugin->run();

}
run_pedigree_online();
